@@ -9,17 +9,35 @@
 import numpy as np
 import pyclothoids as pcloth
 
-from .lane import Lane, RoadMark, LaneSection, Lanes
-from .enumerations import RoadMarkType, MarkRule, ContactPoint, ElementType, ObjectType
+from .lane import Lane, RoadMark, LaneSection, Lanes, RoadLine
+from .enumerations import JunctionType, RoadMarkType, MarkRule, ContactPoint, ElementType, ObjectType
 
 from .geometry import Line, Arc, Spiral, PlanView
 from .opendrive import Road, OpenDrive
 from .links import Junction, Connection, _get_related_lanesection, LaneLinker
-from .exceptions import GeneralIssueInputArguments
+from .exceptions import GeneralIssueInputArguments, NotSameAmountOfLanesError
 
 
 STD_ROADMARK_SOLID = RoadMark(RoadMarkType.solid,0.2)
+
 STD_ROADMARK_BROKEN = RoadMark(RoadMarkType.broken,0.2)
+
+STD_ROADMARK_BROKEN_BROKEN = RoadMark(RoadMarkType.broken_broken)
+STD_ROADMARK_BROKEN_BROKEN.add_specific_road_line(RoadLine(0.2,3,3,0.2,0))
+STD_ROADMARK_BROKEN_BROKEN.add_specific_road_line(RoadLine(0.2,3,3,-0.2,0))
+
+STD_ROADMARK_SOLID_SOLID = RoadMark(RoadMarkType.solid_solid)
+STD_ROADMARK_SOLID_SOLID.add_specific_road_line(RoadLine(0.2,0,0,0.2,0))
+STD_ROADMARK_SOLID_SOLID.add_specific_road_line(RoadLine(0.2,0,0,-0.2,0))
+
+STD_ROADMARK_SOLID_BROKEN = RoadMark(RoadMarkType.solid_broken)
+STD_ROADMARK_SOLID_BROKEN.add_specific_road_line(RoadLine(0.2,0,0,0.2,0))
+STD_ROADMARK_SOLID_BROKEN.add_specific_road_line(RoadLine(0.2,3,3,-0.2,0))
+
+STD_ROADMARK_BROKEN_SOLID = RoadMark(RoadMarkType.broken_solid)
+STD_ROADMARK_BROKEN_SOLID.add_specific_road_line(RoadLine(0.2,0,0,-0.2,0))
+STD_ROADMARK_BROKEN_SOLID.add_specific_road_line(RoadLine(0.2,3,3,0.2,0))
+
 STD_START_CLOTH = 1/1000000000
 
 def standard_lane(offset=3,rm = STD_ROADMARK_BROKEN):
@@ -714,8 +732,6 @@ def create_junction(junction_roads, id, roads, name='my junction'):
 
     """
 
-
-
     junc = Junction(name,id)
     
     for jr in junction_roads:
@@ -735,6 +751,54 @@ def create_junction(junction_roads, id, roads, name='my junction'):
         junc.add_connection(conne2)
     return junc
 
+
+def create_direct_junction(roads, id, name='my direct junction'):
+    """ create_direct_junction creates the junction struct for a set of roads, for a direct junction
+
+        Parameters
+        ----------
+            roads (list of Road): all roads that are building up the direct junction
+
+            id (int): the id of the junction
+            
+            name(str): name of the junction
+            default: 'my direct junction'
+
+        Returns
+        -------
+            junction (Junction): the junction struct ready to use
+
+    """
+
+    junc = Junction(name,id,junction_type=JunctionType.direct)
+    used_road_indexes = []
+    for r in roads:
+        # only check connection once
+        if r.id not in used_road_indexes:
+            used_road_indexes.append(r.id)
+            if r.succ_direct_junction:
+                for dr in r.succ_direct_junction:
+                    used_road_indexes.append(dr)
+                    conn = Connection(r.id,str(dr),ContactPoint.start)
+                    outgoingroad = get_road_by_id(roads,dr)
+                    # _, sign, _ =  _get_related_lanesection(r,get_road_by_id(roads,dr) ) 
+                    _create_junction_links(conn,len(outgoingroad.lanes.lanesections[-1].rightlanes),-1,1,from_offset=outgoingroad.lane_offset_pred)
+                    _create_junction_links(conn,len(outgoingroad.lanes.lanesections[-1].leftlanes),1,1,from_offset=outgoingroad.lane_offset_pred)
+                    junc.add_connection(conn)
+            elif r.pred_direct_junction:
+                for dr in r.pred_direct_junction:
+                    used_road_indexes.append(dr)
+                    conn = Connection(r.id,str(dr),ContactPoint.end)
+                    outgoingroad = get_road_by_id(roads,dr)
+                    # _, sign, _ =  _get_related_lanesection(r,get_road_by_id(roads,dr) ) 
+                    _create_junction_links(conn,len(outgoingroad.lanes.lanesections[-1].rightlanes),-1,1,from_offset=outgoingroad.lane_offset_suc)
+                    _create_junction_links(conn,len(outgoingroad.lanes.lanesections[-1].leftlanes),1,1,from_offset=outgoingroad.lane_offset_suc)
+                    junc.add_connection(conn)
+            else:
+                raise ValueError('Road is not connected to a direct junction')
+
+    return junc
+
 def get_road_by_id(roads,id):
     """ get_road_by_id returns a road based on the road id
 
